@@ -70,5 +70,10 @@ class ApiDeviceType:
     GROUP_SWITCH = "GROUP_SWITCH"
     SCENARIO = "SCENARIO"
     TIMED_POWER = "TIMED_POWER"
-    OUTLET = "OUTLET"
+    IR_DEVICE = "IR_DEVICE"
     THERMOSTAT = "THERMOSTAT"
+    LOCK_GROUP = "LOCK_GROUP"
+    TIMED_SWITCH = "TIMED_SWITCH"
+    LOUVERED_SHUTTER = "LOUVERED_SHUTTER"
+    SOMFY = "SOMFY"
+    ROLLING_SCENARIO = "ROLLING_SCENARIO"
